/***************************************************************************
 *   Copyright (C) 2004 by Kazuki Ohta                                     *
 *   mover@hct.zaq.ne.jp                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kknewcontactdialog.h"
#include "kkcontactdata.h"
#include "kkaddressbookglobalconfig.h"
#include "zipcode.h"

#include <qlabel.h>
#include <qlayout.h>
#include <qvbox.h>
#include <qhbuttongroup.h>
#include <qtoolbutton.h>
#include <qsizepolicy.h>

#include <klocale.h>
#include <kglobal.h>
#include <kconfig.h>
#include <kmessagebox.h>
#include <kdialog.h>
#include <klineedit.h>
#include <kdialogbase.h>
#include <kcombobox.h>
#include <kseparator.h>
#include <kdebug.h>

#define ZIPCODE_LENGTH 7

KKNewContactDialog::KKNewContactDialog( QWidget *parent, const char *name )
	: KDialog( parent, name )
{
	setCaption( i18n("KreetingKard : Add New Contact") );

	init();
}

KKNewContactDialog::~KKNewContactDialog()
{

}

void KKNewContactDialog::init()
{
	checkZipCodeData();

	setupWidgets();

	// first focus
	mFuriganaEdit->setFocus();
}

void KKNewContactDialog::setupWidgets()
{
	QLabel *label;
	QGridLayout *layout;
	QVBoxLayout *mainLayout = new QVBoxLayout( this );

	/* setup Upper side */
	QWidget *upperWidget = new QWidget( this );
	layout = new QGridLayout( upperWidget, 2, 4 );
	layout->setMargin( KDialogBase::marginHint() );
	layout->setSpacing( KDialogBase::spacingHint() );

	label = new QLabel( upperWidget );
	label->setText( i18n("Furigana") );
	mFuriganaEdit = new KLineEdit( upperWidget );
	label->setBuddy( mFuriganaEdit );
	layout->addWidget( label, 0, 1 );
	layout->addWidget( mFuriganaEdit, 0, 2 );

	label = new QLabel( upperWidget );
	label->setText( i18n("Name(*)") );
	mNameEdit = new KLineEdit( upperWidget );
	label->setBuddy( mNameEdit );
	layout->addWidget( label, 1, 1 );
	layout->addWidget( mNameEdit, 1, 2 );

	mNamePostfixCombo = new KComboBox( upperWidget );
	mNamePostfixCombo->insertItem( i18n("Sama") );
	mNamePostfixCombo->insertItem( i18n("Teacher") );
	layout->addWidget( mNamePostfixCombo, 1, 3 );

	mGroupCombo = new KComboBox( upperWidget );
	// insert groups
	QStringList groupList = KKAddressBookGlobalConfig::readGroupList();
	QStringList::ConstIterator it = groupList.begin();
	const QStringList::ConstIterator end = groupList.end();
	for( ; it != end; ++it )
	{
		mGroupCombo->insertItem( *it );		
	}
	layout->addWidget( mGroupCombo, 1, 4 );

	mainLayout->addWidget( upperWidget );


	/* Separator */
	mainLayout->addWidget( new KSeparator( this ) );

	/* setup Lower side */
	// 2004-11-11 Kazuki Ohta <mover@hct.zaq.ne.jp>
	// Should we use Tab widget here?
	QWidget *lowerWidget = new QWidget( this );
	layout = new QGridLayout( lowerWidget, 5, 4 );
	layout->setMargin( KDialogBase::marginHint() );
	layout->setSpacing( KDialogBase::spacingHint() );

	label = new QLabel( lowerWidget );
	label->setText( i18n("ZipCode") );
	mZipCodeEdit = new KLineEdit( lowerWidget );
	mZipCodeEdit->setInputMask( "999-9999" );
	QObject::connect( mZipCodeEdit, SIGNAL( textChanged(const QString &) ),
			  this, SLOT(slotZipCodeChanged(const QString &)) );
	label->setBuddy( mZipCodeEdit );
	layout->addWidget( label, 0, 1 );
	layout->addWidget( mZipCodeEdit, 0, 2 );
	
	label = new QLabel( lowerWidget );
	label->setText( i18n("Address1(*)") );
	mAddress1Edit = new KLineEdit( lowerWidget );
	label->setBuddy( mAddress1Edit );
	layout->addWidget( label, 1, 1 );
	layout->addWidget( mAddress1Edit, 1, 2 );

	label = new QLabel( lowerWidget );
	label->setText( i18n("Address2") );
	mAddress2Edit = new KLineEdit( lowerWidget );
	label->setBuddy( mAddress2Edit );
	layout->addWidget( label, 2, 1 );
	layout->addWidget( mAddress2Edit, 2, 2 );

	label = new QLabel( lowerWidget );
	label->setText( i18n("Phone Number") );
	mPhoneNumberEdit = new KLineEdit( lowerWidget );
	label->setBuddy( mPhoneNumberEdit );
	layout->addWidget( label, 3, 1 );
	layout->addWidget( mPhoneNumberEdit, 3, 2 );

	label = new QLabel( lowerWidget );
	label->setText( i18n("Fax Number") );
	mFaxNumberEdit = new KLineEdit( lowerWidget );
	label->setBuddy( mFaxNumberEdit );
	layout->addWidget( label, 4, 1 );
	layout->addWidget( mFaxNumberEdit, 4, 2 );

	label = new QLabel( lowerWidget );
	label->setText( i18n("Mobile Phone Number") );
	mMobilePhoneNumberEdit = new KLineEdit( lowerWidget );
	label->setBuddy( mMobilePhoneNumberEdit );
	layout->addWidget( label, 5, 1 );
	layout->addWidget( mMobilePhoneNumberEdit, 5, 2 );

	mainLayout->addWidget( lowerWidget );

	/* Separator */
	mainLayout->addWidget( new KSeparator( this ) );

	/* Buttons */
	QHBox *hBox = new QHBox( this );
	hBox->setMargin( 6 );
	hBox->setSpacing( 6 );

	addNextButton = new QToolButton( hBox );
	addNextButton->setText( i18n("Add Next Contact") );
        addNextButton->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
	QObject::connect( addNextButton, SIGNAL( clicked() ),
			  this, SLOT( slotAddNext() ) );

	okButton = new QToolButton( hBox );
	okButton->setText( i18n("OK") );
        okButton->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
	QObject::connect( okButton, SIGNAL( clicked() ),
			  this, SLOT( slotOK() ) );

	cancelButton = new QToolButton( hBox );
	cancelButton->setText( i18n("Cancel") );
        cancelButton->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
	QObject::connect( cancelButton, SIGNAL( clicked() ),
			  this, SLOT( slotCancel() ) );

	mainLayout->addWidget( hBox );
}

void KKNewContactDialog::checkZipCodeData()
{
	KConfig *conf = KGlobal::config();
	conf->setGroup( "KKAddressBook" );

	// check if ZipCode is available
	bool isDownloadZipCode = conf->readBoolEntry( "isDownloadZipCode", false );
	if( isDownloadZipCode == false )
	{
		KMessageBox::information( this, i18n("This is the first time to add contact."
						     "Now KreetingKard starts downloadding the ZipCode data.") );

		// download
		bool isSuccess = ZipCode::instance().update( this );
		conf->writeEntry( "isDownloadZipCode", isSuccess );
	}
}

void KKNewContactDialog::slotZipCodeChanged( const QString &str )
{
	QString zipCode( str );
	zipCode.remove( '-' );

	// check if str is valid for zipcode
	bool ok;
	zipCode.toDouble( &ok );
	if( ok && zipCode.length() == ZIPCODE_LENGTH )
	{
		// 2004-11-11 Kazuki Ohta <mover@hct.zaq.ne.jp>
		// Too Slow
		mAddress1Edit->setText( ZipCode::instance().lookup( zipCode ) );
		mAddress1Edit->setFocus();
	}
}

bool KKNewContactDialog::isValidData()
{
	bool isNameEmpty = mNameEdit->text().isEmpty();
	bool isAddressEmpty = (mAddress1Edit->text().isEmpty() && mAddress2Edit->text().isEmpty());
	if( isNameEmpty
	    || isAddressEmpty )
	{
		KMessageBox::error( this, i18n("Data should at least contain Name and Address data") );

		// Set focus for valid place
		if( isNameEmpty )
			mNameEdit->setFocus();
		else
			mAddress1Edit->setFocus();
		
		return false;
	}
	else
	{
		return true;		
	}
}

void KKNewContactDialog::slotAddNext()
{
	kdDebug() << "slotAddNext()" << endl;

	if( isValidData() )
		done( KKNewContactDialog::AddNext );
}

void KKNewContactDialog::slotOK()
{
	kdDebug() << "slotOK()" << endl;

	if( isValidData() )
		done( KKNewContactDialog::OK );
}

void KKNewContactDialog::slotCancel()
{
	kdDebug() << "slotCancel()" << endl;
	done( KKNewContactDialog::Cancel );
}

KKContactData KKNewContactDialog::getContactData()
{
	return KKContactData( mFuriganaEdit->text(),
			      mNameEdit->text(),
			      mNamePostfixCombo->currentText(),
			      mGroupCombo->currentText(),
			      mZipCodeEdit->text(),
			      mAddress1Edit->text(),
			      mAddress2Edit->text());
}

void KKNewContactDialog::setContactData( const KKContactData & d )
{
	mFuriganaEdit->setText( d.getFurigana() );
	mNameEdit->setText( d.getFullname() );
	mNamePostfixCombo->setCurrentText( d.getNamePostfix() );
	mGroupCombo->setCurrentText( d.getGroup() );
	mZipCodeEdit->setText( d.getZipCode() );
	mAddress1Edit->setText( d.getAddress1() );
	mAddress2Edit->setText( d.getAddress2() );
}
